@@ -948,13 +948,13 @@ def pbdDict_bxReposRoot(
     gitClone('bisos/comeega',  'bisos/comeega', vcMode)
     gitClone('bisos/gatherer',  'bisos/gatherer', vcMode)
     gitClone('bisos/defaults',  'bisos/defaults', vcMode)
-    gitClone('bisos/bxio',  'bisos/bxio', vcMode)
-    gitClone('bisos/bxso',  'bisos/bxso', vcMode)
+    # gitClone('bisos/bxio',  'bisos/bxio', vcMode)
+    # gitClone('bisos/bxso',  'bisos/bxso', vcMode)
     gitClone('bisos/asc',  'bisos/asc', vcMode)    
     gitClone('bisos/apps',  'bisos/apps', vcMode)
     gitClone('bisos/lcnt',  'bisos/lcnt', vcMode)
     gitClone('bisos/mail',  'bisos/mail', vcMode)
-    gitClone('bisos/aais',  'bisos/aais', vcMode)
+    gitClone('bisos/pals',  'bisos/pals', vcMode)
 
     gitCloneBase('bxObjects', 'bxObjects/base', vcMode)
     gitClone('bxObjects/overview',  'bxObjects/overview', vcMode)
